@@ -12,16 +12,17 @@ from typing import Any, Optional, Sequence, Union
 
 import json5
 import shtab
+from filelock import AsyncFileLock
 
 from vectorcode import __version__
 
 logger = logging.getLogger(name=__name__)
 
 
-PathLike = Union[str, Path]
-
-GLOBAL_CONFIG_PATH = os.path.join(
-    os.path.expanduser("~"), ".config", "vectorcode", "config.json"
+GLOBAL_CONFIG_DIR = os.path.join(
+    os.path.expanduser("~"),
+    ".config",
+    "vectorcode",
 )
 GLOBAL_INCLUDE_SPEC = os.path.join(
     os.path.expanduser("~"), ".config", "vectorcode", "vectorcode.include"
@@ -47,6 +48,12 @@ class QueryInclude(StrEnum):
         return f"{self.value.capitalize()}: "
 
 
+class PromptCategory(StrEnum):
+    query = "query"
+    vectorise = "vectorise"
+    ls = "ls"
+
+
 class CliAction(Enum):
     vectorise = "vectorise"
     query = "query"
@@ -59,7 +66,12 @@ class CliAction(Enum):
     clean = "clean"
     prompts = "prompts"
     chunks = "chunks"
-    hooks = "hooks"
+    files = "files"
+
+
+class FilesAction(StrEnum):
+    ls = "ls"
+    rm = "rm"
 
 
 @dataclass
@@ -70,8 +82,8 @@ class Config:
     to_be_deleted: list[str] = field(default_factory=list)
     pipe: bool = False
     action: Optional[CliAction] = None
-    files: list[PathLike] = field(default_factory=list)
-    project_root: Optional[PathLike] = None
+    files: list[Union[str, os.PathLike]] = field(default_factory=list)
+    project_root: Optional[Union[str, Path]] = None
     query: Optional[list[str]] = None
     db_url: str = "http://127.0.0.1:8000"
     embedding_function: str = "SentenceTransformerEmbeddingFunction"  # This should fallback to whatever the default is.
@@ -84,7 +96,7 @@ class Config:
     chunk_size: int = 2500
     overlap_ratio: float = 0.2
     query_multiplier: int = -1
-    query_exclude: list[PathLike] = field(default_factory=list)
+    query_exclude: list[Union[str, os.PathLike]] = field(default_factory=list)
     reranker: Optional[str] = "CrossEncoderReranker"
     reranker_params: dict[str, Any] = field(default_factory=lambda: {})
     check_item: Optional[str] = None
@@ -97,6 +109,9 @@ class Config:
     filetype_map: dict[str, list[str]] = field(default_factory=dict)
     encoding: str = "utf8"
     hooks: bool = False
+    prompt_categories: Optional[list[str]] = None
+    files_action: Optional[FilesAction] = None
+    rm_paths: list[str] = field(default_factory=list)
 
     @classmethod
     async def import_from(cls, config_dict: dict[str, Any]) -> "Config":
@@ -105,20 +120,6 @@ class Config:
         """
         default_config = Config()
         db_path = config_dict.get("db_path")
-        db_url = config_dict.get("db_url")
-        if db_url is None:
-            host = config_dict.get("host")
-            port = config_dict.get("port")
-            if host is not None or port is not None:
-                # TODO: deprecate `host` and `port` in 0.7.0
-                host = host or "127.0.0.1"
-                port = port or 8000
-                db_url = f"http://{host}:{port}"
-                logger.warning(
-                    f'"host" and "port" are deprecated and will be removed in 0.7.0. Use "db_url" (eg. {db_url}).'
-                )
-            else:
-                db_url = "http://127.0.0.1:8000"
 
         if db_path is None:
             db_path = os.path.expanduser("~/.local/share/vectorcode/chromadb/")
@@ -134,7 +135,7 @@ class Config:
                 "embedding_params": config_dict.get(
                     "embedding_params", default_config.embedding_params
                 ),
-                "db_url": db_url,
+                "db_url": config_dict.get("db_url", default_config.db_url),
                 "db_path": db_path,
                 "db_log_path": os.path.expanduser(
                     config_dict.get("db_log_path", default_config.db_log_path)
@@ -214,7 +215,7 @@ def get_cli_parser():
         "--project_root",
         default=None,
         help="Project root to be used as an identifier of the project.",
-    ).complete = shtab.DIRECTORY
+    ).complete = shtab.DIRECTORY  # type:ignore
     shared_parser.add_argument(
         "--pipe",
         "-p",
@@ -226,7 +227,7 @@ def get_cli_parser():
         "--no_stderr",
         action="store_true",
         default=False,
-        help="Supress all STDERR messages.",
+        help="Suppress all STDERR messages.",
     )
     main_parser = argparse.ArgumentParser(
         "vectorcode",
@@ -253,7 +254,7 @@ def get_cli_parser():
     )
     vectorise_parser.add_argument(
         "file_paths", nargs="*", help="Paths to files to be vectorised."
-    ).complete = shtab.FILE
+    ).complete = shtab.FILE  # type:ignore
     vectorise_parser.add_argument(
         "--recursive",
         "-r",
@@ -297,7 +298,7 @@ def get_cli_parser():
     )
     query_parser.add_argument(
         "--exclude", nargs="*", help="Files to exclude from query results."
-    ).complete = shtab.FILE
+    ).complete = shtab.FILE  # type:ignore
     query_parser.add_argument(
         "--absolute",
         default=False,
@@ -313,16 +314,6 @@ def get_cli_parser():
     )
 
     subparsers.add_parser("drop", parents=[shared_parser], help="Remove a collection.")
-    hooks_parser = subparsers.add_parser(
-        "hooks", parents=[shared_parser], help="Inject git hooks."
-    )
-    hooks_parser.add_argument(
-        "--force",
-        "-f",
-        action="store_true",
-        default=False,
-        help="Override existing VectorCode hooks.",
-    )
 
     init_parser = subparsers.add_parser(
         "init",
@@ -369,11 +360,19 @@ def get_cli_parser():
         help="Remove empty collections in the database.",
     )
 
-    subparsers.add_parser(
+    prompts_parser = subparsers.add_parser(
         "prompts",
         parents=[shared_parser],
         help="Print a list of guidelines intended to be used as system prompts for an LLM.",
     )
+    prompts_parser.add_argument(
+        "prompt_categories",
+        choices=[str(i) for i in PromptCategory],
+        type=PromptCategory,
+        nargs="*",
+        help="The subcommand(s) to get the prompts for. When not provided, VectorCode will print the prompts for `query`.",
+        default=None,
+    )
 
     chunks_parser = subparsers.add_parser(
         "chunks",
@@ -382,7 +381,26 @@ def get_cli_parser():
     )
     chunks_parser.add_argument(
         "file_paths", nargs="*", help="Paths to files to be chunked."
-    ).complete = shtab.FILE
+    ).complete = shtab.FILE  # type:ignore
+
+    files_parser = subparsers.add_parser(
+        "files", parents=[shared_parser], help="Manipulate files from a collection."
+    )
+    files_subparser = files_parser.add_subparsers(
+        dest="files_action", required=True, title="Collecton file operations"
+    )
+    files_subparser.add_parser(
+        "ls", parents=[shared_parser], help="List files in the collection."
+    )
+    files_rm_parser = files_subparser.add_parser(
+        "rm", parents=[shared_parser], help="Remove files in the collection."
+    )
+    files_rm_parser.add_argument(
+        "rm_paths",
+        nargs="+",
+        default=None,
+        help="Files to be removed from the collection.",
+    )
     return main_parser
 
 
@@ -425,8 +443,13 @@ async def parse_cli_args(args: Optional[Sequence[str]] = None):
             configs_items["chunk_size"] = main_args.chunk_size
             configs_items["overlap_ratio"] = main_args.overlap
             configs_items["encoding"] = main_args.encoding
-        case "hooks":
-            configs_items["force"] = main_args.force
+        case "prompts":
+            configs_items["prompt_categories"] = main_args.prompt_categories
+        case "files":
+            configs_items["files_action"] = main_args.files_action
+            match main_args.files_action:
+                case FilesAction.rm:
+                    configs_items["rm_paths"] = main_args.rm_paths
     return Config(**configs_items)
 
 
@@ -443,11 +466,15 @@ def expand_envs_in_dict(d: dict):
                 stack.append(curr[k])
 
 
-async def load_config_file(path: Optional[PathLike] = None):
-    """Load config file from ~/.config/vectorcode/config.json"""
+async def load_config_file(path: Optional[Union[str, Path]] = None):
+    """Load config file from ~/.config/vectorcode/config.json(5)"""
     if path is None:
-        path = GLOBAL_CONFIG_PATH
-    if os.path.isfile(path):
+        for name in ("config.json5", "config.json"):
+            p = os.path.join(GLOBAL_CONFIG_DIR, name)
+            if os.path.isfile(p):
+                path = str(p)
+                break
+    if path and os.path.isfile(path):
         logger.debug(f"Loading config from {path}")
         with open(path) as fin:
             content = fin.read()
@@ -466,7 +493,7 @@ async def load_config_file(path: Optional[PathLike] = None):
     return Config()
 
 
-async def find_project_config_dir(start_from: PathLike = "."):
+async def find_project_config_dir(start_from: Union[str, Path] = "."):
     """Returns the project-local config directory."""
     current_dir = Path(start_from).resolve()
     project_root_anchors = [".vectorcode", ".git"]
@@ -486,7 +513,7 @@ async def find_project_config_dir(start_from: PathLike = "."):
 
 
 def find_project_root(
-    start_from: PathLike, root_anchor: PathLike = ".vectorcode"
+    start_from: Union[str, Path], root_anchor: Union[str, Path] = ".vectorcode"
 ) -> str | None:
     start_from = Path(start_from)
     if os.path.isfile(start_from):
@@ -500,7 +527,7 @@ def find_project_root(
         start_from = start_from.parent
 
 
-async def get_project_config(project_root: PathLike) -> Config:
+async def get_project_config(project_root: Union[str, Path]) -> Config:
     """
     Load config file for `project_root`.
     Fallback to global config, and then default config.
@@ -520,7 +547,7 @@ async def get_project_config(project_root: PathLike) -> Config:
     return config
 
 
-def expand_path(path: PathLike, absolute: bool = False) -> PathLike:
+def expand_path(path: Union[str, Path], absolute: bool = False) -> Union[str, Path]:
     expanded = os.path.expanduser(os.path.expandvars(path))
     if absolute:
         return os.path.abspath(expanded)
@@ -528,21 +555,21 @@ def expand_path(path: PathLike, absolute: bool = False) -> PathLike:
 
 
 async def expand_globs(
-    paths: list[PathLike], recursive: bool = False, include_hidden: bool = False
-) -> list[PathLike]:
+    paths: Sequence[os.PathLike | str],
+    recursive: bool = False,
+    include_hidden: bool = False,
+) -> list[str]:
     result = set()
-    stack = paths
+    stack = list(str(i) for i in paths)
     while stack:
         curr = stack.pop()
         if os.path.isfile(curr):
             result.add(expand_path(curr))
         elif "**" in str(curr):
-            stack.extend(
-                glob.glob(str(curr), recursive=True, include_hidden=include_hidden)
-            )
+            stack.extend(glob.glob(curr, recursive=True, include_hidden=include_hidden))
         elif "*" in str(curr):
             stack.extend(
-                glob.glob(str(curr), recursive=recursive, include_hidden=include_hidden)
+                glob.glob(curr, recursive=recursive, include_hidden=include_hidden)
             )
         elif os.path.isdir(curr) and recursive:
             stack.extend(
@@ -616,3 +643,31 @@ def config_logging(
         handlers=handlers,
         level=level,
     )
+
+
+class LockManager:
+    """
+    A class that manages file locks that protects the database files in daemon processes (LSP, MCP).
+    """
+
+    __locks: dict[str, AsyncFileLock]
+    singleton: Optional["LockManager"] = None
+
+    def __new__(cls) -> "LockManager":
+        if cls.singleton is None:
+            cls.singleton = super().__new__(cls)
+            cls.singleton.__locks = {}
+        return cls.singleton
+
+    def get_lock(self, path: str | os.PathLike) -> AsyncFileLock:
+        path = str(expand_path(str(path), True))
+        if os.path.isdir(path):
+            lock_file = os.path.join(path, "vectorcode.lock")
+            logger.info(f"Creating {lock_file} for locking.")
+            if not os.path.isfile(lock_file):
+                with open(lock_file, mode="w") as fin:
+                    fin.write("")
+            path = lock_file
+        if self.__locks.get(path) is None:
+            self.__locks[path] = AsyncFileLock(path)  # pyright: ignore[reportArgumentType]
+        return self.__locks[path]
